==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebCheckboxDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { WebCheckboxBaseDescription } from "./WebCheckboxBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebCheckboxDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCheckboxDescription, _super);
    function WebCheckboxDescription() {
        var _this = _super.call(this) || this;
        _this.ac = false;
        return _this;
    }
    WebCheckboxDescription.prototype.get_type = function () {
        return "WebCheckbox";
    };
    Object.defineProperty(WebCheckboxDescription.prototype, "indeterminate", {
        get: function () {
            return this.ac;
        },
        set: function (a) {
            this.ac = a;
            this.e("Indeterminate");
        },
        enumerable: true,
        configurable: true
    });
    WebCheckboxDescription.$t = markType(WebCheckboxDescription, 'WebCheckboxDescription', WebCheckboxBaseDescription.$);
    return WebCheckboxDescription;
}(WebCheckboxBaseDescription));
export { WebCheckboxDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebCheckboxDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { WebCheckboxBaseDescription } from "./WebCheckboxBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var WebCheckboxDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebCheckboxDescription, _super);
    function WebCheckboxDescription() {
        var _this = _super.call(this) || this;
        _this.ae = false;
        return _this;
    }
    WebCheckboxDescription.prototype.get_type = function () {
        return "WebCheckbox";
    };
    Object.defineProperty(WebCheckboxDescription.prototype, "indeterminate", {
        get: function () {
            return this.ae;
        },
        set: function (a) {
            this.ae = a;
            this.g("Indeterminate");
        },
        enumerable: false,
        configurable: true
    });
    WebCheckboxDescription.$t = markType(WebCheckboxDescription, 'WebCheckboxDescription', WebCheckboxBaseDescription.$);
    return WebCheckboxDescription;
}(WebCheckboxBaseDescription));
export { WebCheckboxDescription };
